[][src]Struct dync::CopyValueMut

pub struct CopyValueMut<'a> { /* fields omitted */ }

A generic mutable Copy value reference.

Methods

impl<'a> CopyValueMut<'a>[src]

pub fn size(&self) -> usize[src]

Get the size of the value pointed-to by this reference.

pub fn value_type_id(&self) -> TypeId[src]

Get the TypeId of the referenced value.

pub fn is<T: 'static>(&self) -> bool[src]

Returns true if this referenced value's type is the same as T.

pub fn new<T: Elem>(typed: &'a mut T) -> CopyValueMut<'a>[src]

Create a new CopyValueMut from a typed mutable reference.

pub fn copy(self, other: CopyValueRef<'a>) -> Option<Self>[src]

Copy value from other to self and return Self.

This function returns None if the values have different types.

pub fn swap(&mut self, other: &mut CopyValueMut)[src]

Swap the values between other and self.

pub fn downcast<T: Elem>(self) -> Option<&'a mut T>[src]

Downcast this value reference into a borrowed T type. Return None if the downcast fails.