[−][src]Struct dync::Meta
Defines a meta struct containing information about a type but not the type itself.
Note that here V would typically represent a pointer type.
Fields
elem: ElemInfovtable: VTrait Implementations
impl<V: Clone> Clone for Meta<V>[src]
impl<V: Copy> Copy for Meta<V>[src]
impl<V: Debug> Debug for Meta<V>[src]
impl<V: Eq> Eq for Meta<V>[src]
impl<'a, V> From<&'a VecCopy<V>> for Meta<VTableRef<'a, V>>[src]
impl<'a, V: Clone + HasDrop> From<&'a VecDyn<V>> for Meta<VTableRef<'a, V>>[src]
impl<'a, V> From<CopyValueRef<'a, V>> for Meta<VTableRef<'a, V>>[src]
fn from(val: CopyValueRef<'a, V>) -> Meta<VTableRef<'a, V>>[src]
impl<'a, V> From<Slice<'a, V>> for Meta<VTableRef<'a, V>>[src]
impl<'a, V> From<SliceCopy<'a, V>> for Meta<VTableRef<'a, V>>[src]
impl<'a, V> From<SliceCopyMut<'a, V>> for Meta<VTableRef<'a, V>>[src]
fn from(slice: SliceCopyMut<'a, V>) -> Self[src]
impl<'a, V> From<SliceMut<'a, V>> for Meta<VTableRef<'a, V>>[src]
impl<'a, V: HasDrop> From<ValueMut<'a, V>> for Meta<VTableRef<'a, V>>[src]
impl<'a, V: HasDrop> From<ValueRef<'a, V>> for Meta<VTableRef<'a, V>>[src]
impl<V: Hash> Hash for Meta<V>[src]
fn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
H: Hasher,
impl<V: PartialEq> PartialEq<Meta<V>> for Meta<V>[src]
impl<V> StructuralEq for Meta<V>[src]
impl<V> StructuralPartialEq for Meta<V>[src]