[−][src]Struct dync::ValueMut
A generic mutable value reference into a buffer.
Implementations
impl<'a, V: HasDrop> ValueMut<'a, V>[src]
pub fn new<T: Any>(typed: &'a mut T) -> ValueMut<'a, V> where
V: VTable<T>, [src]
V: VTable<T>,
Create a new ValueRef from a typed reference.
impl<'a, V: ?Sized + HasDrop> ValueMut<'a, V>[src]
pub fn size(&self) -> usize[src]
Get the size of the value pointed-to by this reference.
pub fn value_type_id(&self) -> TypeId[src]
Get the TypeId of the referenced value.
pub fn is<T: 'static>(&self) -> bool[src]
Returns true if this referenced value's type is the same as T.
pub fn swap<'b>(&mut self, other: &mut ValueMut<'b, V>)[src]
Swap the values between other and self.
pub fn assign<B: GetBytesMut>(&mut self, value: Value<B, V>)[src]
Moves the given value into self.
pub fn clone_from_other<'b>(
&mut self,
other: impl Into<ValueRef<'b, V>>
) -> Result<(), Error> where
V: HasClone + 'b, [src]
&mut self,
other: impl Into<ValueRef<'b, V>>
) -> Result<(), Error> where
V: HasClone + 'b,
Clone other into self.
This function will call drop on any values stored in self.
pub fn clone_value(&self) -> Value<Box<[u8]>, V> where
V: HasClone + Clone, [src]
V: HasClone + Clone,
Clone the referenced value.
Unlike the Clone trait, this function will produce an owned clone of the value pointed to
by this value reference.
pub fn clone_small_value(&self) -> Value<usize, V> where
V: HasClone + Clone, [src]
V: HasClone + Clone,
Clone the referenced value.
Unlike the Clone trait, this function will produce an owned clone of the value pointed to
by this value reference.
This version of clone_value tries to fit the underlying value into a usize sized value,
and panics if that fails.
pub fn downcast<T: 'static>(self) -> Option<&'a mut T>[src]
Downcast this value reference into a borrowed T type. Return None if the downcast fails.
pub fn upcast<U: ?Sized + HasDrop + From<V>>(self) -> ValueMut<'a, U> where
V: Clone, [src]
V: Clone,
A consuming upcast that carries the lifetime of the underlying value reference.
pub fn upcast_mut<U: ?Sized + HasDrop + From<V>>(&mut self) -> ValueMut<U> where
V: Clone, [src]
V: Clone,
Create a new mutable value reference upcast from the current one.
pub fn reborrow(&self) -> ValueRef<V>[src]
pub fn reborrow_mut(&mut self) -> ValueMut<V>[src]