[][src]Struct dync::ValueRef

pub struct ValueRef<'a, V> { /* fields omitted */ }

A generic value reference into a buffer.

Methods

impl<'a, V> ValueRef<'a, V>[src]

pub fn size(&self) -> usize[src]

Get the size of the value pointed-to by this reference.

pub fn value_type_id(&self) -> TypeId[src]

Get the TypeId of the referenced value.

pub fn is<T: 'static>(&self) -> bool[src]

Returns true if this referenced value's type is the same as T.

pub fn new<T: Any + DropBytes>(typed: &'a T) -> ValueRef<'a, V> where
    V: VTable<T>, 
[src]

Create a new ValueRef from a typed reference.

pub fn clone_value(&self) -> Value<Box<[u8]>, V> where
    V: HasClone + Clone
[src]

Clone the referenced value.

Unlike the Clone trait, this function will produce an owned clone of the value pointed to by this value reference.

pub fn downcast<T: 'static>(self) -> Option<&'a T>[src]

Downcast this value reference into a borrowed T type. Return None if the downcast fails.