[−][src]Type Definition dync::SmallValue
type SmallValue<V> = Value<MaybeUninit<usize>, V>;
Implementations
impl<V: HasDrop> SmallValue<V>[src]
pub fn try_new<T: Any + DropBytes>(
value: T
) -> Option<Value<MaybeUninit<usize>, V>> where
V: VTable<T>, [src]
value: T
) -> Option<Value<MaybeUninit<usize>, V>> where
V: VTable<T>,
pub fn new<T: Any + DropBytes>(value: T) -> Value<MaybeUninit<usize>, V> where
V: VTable<T>, [src]
V: VTable<T>,
This function will panic if the given type does not fit into a usize.
impl<V: ?Sized + HasDrop> SmallValue<V>[src]
pub fn upcast<U: HasDrop + From<V>>(self) -> SmallValue<U> where
V: Clone, [src]
V: Clone,
pub fn into_raw_parts(self) -> (MaybeUninit<usize>, TypeId, usize, Ptr<V>)[src]
Convert this value into its destructured parts.
The caller must insure that the memory allocated by the returned bytes is freed.