[][src]Struct dync::ValueMut

pub struct ValueMut<'a, V> { /* fields omitted */ }

A generic mutable value reference into a buffer.

Methods

impl<'a, V> ValueMut<'a, V>[src]

pub fn size(&self) -> usize[src]

Get the size of the value pointed-to by this reference.

pub fn value_type_id(&self) -> TypeId[src]

Get the TypeId of the referenced value.

pub fn is<T: 'static>(&self) -> bool[src]

Returns true if this referenced value's type is the same as T.

pub fn new<T: Any>(typed: &'a mut T) -> ValueMut<'a, V> where
    V: VTable<T>, 
[src]

Create a new ValueRef from a typed reference.

pub fn swap<'b>(&mut self, other: &mut ValueMut<'b, V>)[src]

Swap the values between other and self.

pub fn clone_from<'b>(&mut self, other: impl Into<ValueRef<'b, V>>) where
    V: HasClone + 'b, 
[src]

Clone other into self.

This function will call drop on any values stored in self.

pub fn downcast<T: 'static>(self) -> Option<&'a mut T>[src]

Downcast this value reference into a borrowed T type. Return None if the downcast fails.